==> haskell-lucid-2.11.20250303-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lucid
version:              2.11.20250303
visibility:           public
id:                   lucid-2.11.20250303-7NZpW0SgCjuGUrtHfs61h0
key:                  lucid-2.11.20250303-7NZpW0SgCjuGUrtHfs61h0
license:              BSD-3-Clause
copyright:            2014-2021 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             https://github.com/chrisdone/lucid
synopsis:             Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.

    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)

    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')

    * For more, read <https://chrisdone.com/posts/lucid the blog post>

    See the "Lucid" module for more documentation.

category:             Web
abi:                  0ee6c5329f76101b92c549a4e7d7c5ea
exposed:              True
exposed-modules:      Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20250303
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20250303
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20250303
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lucid
hs-libraries:         HSlucid-2.11.20250303-7NZpW0SgCjuGUrtHfs61h0
depends:
    base-4.17.2.1 blaze-builder-0.4.4-B5FT87wlflF4r5SJ13FU3M
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-6tleuNdu8X41J3b2E1oOOY
    mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html:         /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lucid-2.11.20250303-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lucid
version:              2.11.20250303
visibility:           public
id:                   lucid-2.11.20250303-96iFcytj25KKAWjNlaSLnh
key:                  lucid-2.11.20250303-96iFcytj25KKAWjNlaSLnh
license:              BSD-3-Clause
copyright:            2014-2021 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             https://github.com/chrisdone/lucid
synopsis:             Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.

    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)

    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')

    * For more, read <https://chrisdone.com/posts/lucid the blog post>

    See the "Lucid" module for more documentation.

category:             Web
abi:                  c81ec1651f6365a9a330c6ca4951e642
exposed:              True
exposed-modules:      Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20250303
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20250303
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20250303
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lucid
hs-libraries:         HSlucid-2.11.20250303-96iFcytj25KKAWjNlaSLnh
depends:
    base-4.17.2.1 blaze-builder-0.4.4-LpfpwWComBBEX8xWeKu4OT
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-GXwYNb6ixbL0AOxKKxOK7
    mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html:         /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
